@@ -10,11 +10,13 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: scriptLibInfo.php 3340 2010-07-05 06:46:22Z fishbone $
+ * @version    SVN: $Id: scriptLibInfo.php 3399 2010-07-18 11:19:46Z fishbone $
  * @link       http://www.magic3.org
  */
 class ScriptLibInfo
 {
+	private static $jQueryVer = 0;			// 使用するjQueryのバージョン(0=2.6、1=最新)
+	
 	// Javascriptライブラリ(DBでの設定値)
 	// ベースライブラリ
 	const LIB_JQUERY_UI				= 'jquery-ui';
@@ -37,6 +39,7 @@ class ScriptLibInfo
 	const LIB_JQUERY_COOKIE			= 'jquery.cookie';
 	const LIB_JQUERY_FORMAT			= 'jquery.format';
 	const LIB_JQUERY_FORMTIPS		= 'jquery.formtips';
+	const LIB_JQUERY_FACEBOX		= 'jquery.facebox';
 	// jQuery UI
 	const LIB_JQUERY_UI_WIDGETS_ACCORDION		= 'jquery-ui.accordion';		// Widgets Accordion
 	const LIB_JQUERY_UI_WIDGETS_AUTOCOMPLETE	= 'jquery-ui.autocomplete';		// Widgets Autocomplete
@@ -65,10 +68,15 @@ class ScriptLibInfo
 	const JQUERY_HOVERINTENT_FILENAME	= 'jquery/jquery.hoverIntent.min.js';
 	const JQUERY_TABLEDND_FILENAME		= 'jquery/jquery.tablednd_0_5.js';
 	const JQUERY_TABLEDND_CSS			= 'jquery/jquery.tablednd.css';
-	const JQUERY_SIMPLEMODAL_FILENAME	= 'jquery/jquery.simplemodal-1.2.3.pack.js';
+	const JQUERY_SIMPLEMODAL_FILENAME	= 'jquery/jquery.simplemodal-1.3.5.min.js';
 	const JQUERY_COOKIE_FILENAME		= 'jquery/jquery.cookie.js';
 	const JQUERY_FORMAT_FILENAME		= 'jquery/jquery.format.1.03.js';
 	const JQUERY_FORMTIPS_FILENAME		= 'jquery/jquery.formtips.1.2.packed.js';
+	const JQUERY_FACEBOX_FILENAME		= 'jquery/facebox.js';
+	const JQUERY_FACEBOX_CSS			= 'jquery/facebox.css';
+
+	// ライブラリの公式サイトのURL
+	const JQUERY_FACEBOX_URL			= 'http://defunkt.github.com/facebox/';
 	
 	// ファイル名
 	const JQUERY_FILENAME			= 'jquery-1.2.6.pack.js';					// JQuery
@@ -90,36 +98,70 @@ class ScriptLibInfo
 	const JQUERY_UI_WIDGETS_TABS_FILENAME			= 'jquery/ui/1.8.2/jquery.ui.tabs.min.js';				// Widgets Tabs
 	const JQUERY_UI_EFFECTS_FILENAME				= 'jquery/ui/1.8.2/jquery.effects.min.js';					// Effects
 	
-	// 設定ファイル
-	//const FCKEDITOR_CONFIG			= 'm3/fckconfig.js';		// FCKEditor
-	
 	/**
 	 * コンストラクタ
 	 */
 	function __construct()
 	{
 	}
+	/**
+	 * jQueryのバージョンを設定
+	 *
+	 * @param int			$version	jQueryのバージョン(0=v2.6、1=最新)
+	 */
+	static function setJQueryVer($version)
+	{
+		self::$jQueryVer = $version;
+	}
+	/**
+	 * jQueryファイル名取得
+	 *
+	 * @param  int    $type	ファイルの種別(0=jQuery、1=jQuery UI Core、2=jQuery UI Plus)
+	 * @return string		jQueryファイル名を取得
+	 */
+	static function getJQueryFilename($type = 0)
+	{
+		$filename = '';
+		if ($type == 0){	// Core
+			switch (self::$jQueryVer){
+				case 0:		// デフォルトのとき
+					$filename = self::JQUERY_FILENAME;	// jquery
+					break;
+				case 1:		// 最新のとき
+					$filename = self::JQUERY_L_FILENAME;	// jquery
+					break;
+			}
+		} else if ($type == 1){	// Core
+			switch (self::$jQueryVer){
+				case 0:		// デフォルトのとき
+					$filename = self::JQUERY_UI_CORE_FILENAME;	// jquery
+					break;
+				case 1:		// 最新のとき
+					$filename = self::JQUERY_L_UI_CORE_FILENAME;	// jquery UI
+					break;
+			}
+		} else if ($type == 2){	// Plus
+			switch (self::$jQueryVer){
+				case 0:		// デフォルトのとき
+					$filename = self::JQUERY_UI_PLUS_FILENAME;	// jquery
+					break;
+				case 1:		// 最新のとき
+					$filename = self::JQUERY_L_UI_PLUS_FILENAME;	// jquery UI
+					break;
+			}
+		}
+		return $filename;
+	}
 	/**
 	 * ライブラリ情報取得
 	 *
 	 * @return array		ライブラリ情報
 	 */
-	function getLib()
+	static function getLib()
 	{
 		$libs = array(self::LIB_MD5					=>	array(	'script' => array(self::MD5_FILENAME)),			// MD5
 					self::LIB_FCKEDITOR				=>	array(	'script' => array(self::FCKEDITOR_FILENAME)),	// FCKEditor
-					self::LIB_JQUERY_UI				=>	array(	'script' => array(self::JQUERY_UI_CORE_FILENAME)),	// jquery ui
-					self::LIB_JQUERY_UI_PLUS		=>	array(	'script' => array(self::JQUERY_UI_PLUS_FILENAME)),	// jquery ui plus(追加分)
-					// jQuery UI
-					self::LIB_JQUERY_UI_WIDGETS_ACCORDION		=> array(	'script' => array(self::JQUERY_UI_WIDGETS_ACCORDION_FILENAME)),		// Widgets Accordion
-					self::LIB_JQUERY_UI_WIDGETS_AUTOCOMPLETE	=> array(	'script' => array(self::JQUERY_UI_WIDGETS_AUTOCOMPLETE_FILENAME)),		// Widgets Autocomplete
-					self::LIB_JQUERY_UI_WIDGETS_BUTTON			=> array(	'script' => array(self::JQUERY_UI_WIDGETS_BUTTON_FILENAME)),		// Widgets Button
-					self::LIB_JQUERY_UI_WIDGETS_DATEPICKER		=> array(	'script' => array(self::JQUERY_UI_WIDGETS_DATEPICKER_FILENAME)),		// Widgets Datepicker
-					self::LIB_JQUERY_UI_WIDGETS_DIALOG			=> array(	'script' => array(self::JQUERY_UI_WIDGETS_DIALOG_FILENAME)),		// Widgets Dialog
-					self::LIB_JQUERY_UI_WIDGETS_PROGRESSBAR		=> array(	'script' => array(self::JQUERY_UI_WIDGETS_PROGRESSBAR_FILENAME)),		// Widgets Progressbar
-					self::LIB_JQUERY_UI_WIDGETS_SLIDER			=> array(	'script' => array(self::JQUERY_UI_WIDGETS_SLIDER_FILENAME)),		// Widgets Slider
-					self::LIB_JQUERY_UI_WIDGETS_TABS			=> array(	'script' => array(self::JQUERY_UI_WIDGETS_TABS_FILENAME)),		// Widgets Tabs
-					self::LIB_JQUERY_UI_EFFECTS					=> array(	'script' => array(self::JQUERY_UI_EFFECTS_FILENAME)),		// Effects
+					
 					// jQueryライブラリ
 					self::LIB_JQUERY_EASING			=>	array(	'script' => array(self::JQUERY_EASING_FILENAME)),		// jquery.easing用のファイル
 					self::LIB_JQUERY_JCAROUSEL		=>	array(	'script' => array(self::JQUERY_JCAROUSEL_FILENAME)),// jquery.jcarousel用のファイル
@@ -139,7 +181,33 @@ class ScriptLibInfo
 					self::LIB_JQUERY_SIMPLEMODAL	=>	array(	'script' => array(self::JQUERY_SIMPLEMODAL_FILENAME)),// jquery.simplemodal用のファイル
 					self::LIB_JQUERY_COOKIE			=>	array(	'script' => array(self::JQUERY_COOKIE_FILENAME)),
 					self::LIB_JQUERY_FORMAT			=>	array(	'script' => array(self::JQUERY_FORMAT_FILENAME)),
-					self::LIB_JQUERY_FORMTIPS		=>	array(	'script' => array(self::JQUERY_FORMTIPS_FILENAME)));
+					self::LIB_JQUERY_FORMTIPS		=>	array(	'script' => array(self::JQUERY_FORMTIPS_FILENAME)),
+					self::LIB_JQUERY_FACEBOX		=>	array(	'script' => array(self::JQUERY_FACEBOX_FILENAME),	// jquery.facebox用のファイル
+																'css'	=> array(self::JQUERY_FACEBOX_CSS),
+																'url'	=> self::JQUERY_FACEBOX_URL));
+					
+		// 使用するjQueryバージョンに合わせてファイルを追加
+		switch (self::$jQueryVer){
+			case 0:		// デフォルトのとき
+				$libs[self::LIB_JQUERY_UI] = array(	'script' => array(self::JQUERY_UI_CORE_FILENAME));	// jquery ui
+				$libs[self::LIB_JQUERY_UI_PLUS] = array(	'script' => array(self::JQUERY_UI_PLUS_FILENAME));	// jquery ui plus(追加分)
+				break;
+			case 1:		// 最新のとき
+				$libs[self::LIB_JQUERY_UI] = array(	'script' => array(self::JQUERY_L_UI_CORE_FILENAME));	// jquery ui
+				$libs[self::LIB_JQUERY_UI_PLUS] = array(	'script' => array(self::JQUERY_L_UI_PLUS_FILENAME));	// jquery ui plus(追加分)
+				
+				// jQuery UI
+				$libs[self::LIB_JQUERY_UI_WIDGETS_ACCORDION]	= array(	'script' => array(self::JQUERY_UI_WIDGETS_ACCORDION_FILENAME));		// Widgets Accordion
+				$libs[self::LIB_JQUERY_UI_WIDGETS_AUTOCOMPLETE] = array(	'script' => array(self::JQUERY_UI_WIDGETS_AUTOCOMPLETE_FILENAME));	// Widgets Autocomplete
+				$libs[self::LIB_JQUERY_UI_WIDGETS_BUTTON]		= array(	'script' => array(self::JQUERY_UI_WIDGETS_BUTTON_FILENAME));		// Widgets Button
+				$libs[self::LIB_JQUERY_UI_WIDGETS_DATEPICKER]	= array(	'script' => array(self::JQUERY_UI_WIDGETS_DATEPICKER_FILENAME));	// Widgets Datepicker
+				$libs[self::LIB_JQUERY_UI_WIDGETS_DIALOG]		= array(	'script' => array(self::JQUERY_UI_WIDGETS_DIALOG_FILENAME));		// Widgets Dialog
+				$libs[self::LIB_JQUERY_UI_WIDGETS_PROGRESSBAR]	= array(	'script' => array(self::JQUERY_UI_WIDGETS_PROGRESSBAR_FILENAME));	// Widgets Progressbar
+				$libs[self::LIB_JQUERY_UI_WIDGETS_SLIDER]		= array(	'script' => array(self::JQUERY_UI_WIDGETS_SLIDER_FILENAME));		// Widgets Slider
+				$libs[self::LIB_JQUERY_UI_WIDGETS_TABS]			= array(	'script' => array(self::JQUERY_UI_WIDGETS_TABS_FILENAME));			// Widgets Tabs
+				$libs[self::LIB_JQUERY_UI_EFFECTS]				= array(	'script' => array(self::JQUERY_UI_EFFECTS_FILENAME));				// Effects
+				break;
+		}
 		return $libs;
 	}
 	/**
@@ -152,19 +220,23 @@ class ScriptLibInfo
 		static $jQueryUiInfo;		// jQuery UIの情報
 		
 		if (!isset($jQueryUiInfo)){
-			$jQueryUiInfo = array(
-				self::LIB_JQUERY_UI_WIDGETS_ACCORDION		=> array(self::LIB_JQUERY_UI),		// Widgets Accordion
-				self::LIB_JQUERY_UI_WIDGETS_AUTOCOMPLETE	=> array(self::LIB_JQUERY_UI),		// Widgets Autocomplete
-				self::LIB_JQUERY_UI_WIDGETS_BUTTON			=> array(self::LIB_JQUERY_UI),		// Widgets Button
-				self::LIB_JQUERY_UI_WIDGETS_DATEPICKER		=> array(self::LIB_JQUERY_UI),		// Widgets Datepicker
-				self::LIB_JQUERY_UI_WIDGETS_DIALOG			=> array(self::LIB_JQUERY_UI,		// Widgets Dialog
-																		self::LIB_JQUERY_UI_PLUS,
-																		self::LIB_JQUERY_UI_WIDGETS_BUTTON),
-				self::LIB_JQUERY_UI_WIDGETS_PROGRESSBAR		=> array(self::LIB_JQUERY_UI),		// Widgets Progressbar
-				self::LIB_JQUERY_UI_WIDGETS_SLIDER			=> array(self::LIB_JQUERY_UI),		// Widgets Slider
-				self::LIB_JQUERY_UI_WIDGETS_TABS			=> array(self::LIB_JQUERY_UI),		// Widgets Tabs
-				self::LIB_JQUERY_UI_EFFECTS					=> array(self::LIB_JQUERY_UI)		// Effects
-			);
+			if (self::$jQueryVer == 0){		// デフォルトのとき
+				$jQueryUiInfo = array();
+			} else {
+				$jQueryUiInfo = array(
+					self::LIB_JQUERY_UI_WIDGETS_ACCORDION		=> array(self::LIB_JQUERY_UI),		// Widgets Accordion
+					self::LIB_JQUERY_UI_WIDGETS_AUTOCOMPLETE	=> array(self::LIB_JQUERY_UI),		// Widgets Autocomplete
+					self::LIB_JQUERY_UI_WIDGETS_BUTTON			=> array(self::LIB_JQUERY_UI),		// Widgets Button
+					self::LIB_JQUERY_UI_WIDGETS_DATEPICKER		=> array(self::LIB_JQUERY_UI),		// Widgets Datepicker
+					self::LIB_JQUERY_UI_WIDGETS_DIALOG			=> array(self::LIB_JQUERY_UI,		// Widgets Dialog
+																			self::LIB_JQUERY_UI_PLUS,
+																			self::LIB_JQUERY_UI_WIDGETS_BUTTON),
+					self::LIB_JQUERY_UI_WIDGETS_PROGRESSBAR		=> array(self::LIB_JQUERY_UI),		// Widgets Progressbar
+					self::LIB_JQUERY_UI_WIDGETS_SLIDER			=> array(self::LIB_JQUERY_UI),		// Widgets Slider
+					self::LIB_JQUERY_UI_WIDGETS_TABS			=> array(self::LIB_JQUERY_UI),		// Widgets Tabs
+					self::LIB_JQUERY_UI_EFFECTS					=> array(self::LIB_JQUERY_UI)		// Effects
+				);
+			}
 		}
 		return $jQueryUiInfo;
 	}
