@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainDb.php 3131 2010-05-14 07:07:41Z fishbone $
+ * @version    SVN: $Id: admin_mainDb.php 3407 2010-07-20 05:05:44Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -2076,9 +2076,11 @@ class admin_mainDb extends BaseDb
 	 * @param string  $url			URL
 	 * @param bool    $visible		表示状態
 	 * @param int     $newId		新規ID
+	 * @param string  $contentType	リンク先コンテンツタイプ
+	 * @param string  $contentId	リンク先コンテンツID
 	 * @return bool					true = 成功、false = 失敗
 	 */
-	function addMenuItem($menuId, $parentId, $name, $desc, $index, $type, $linkType, $url, $visible, &$newId)
+	function addMenuItem($menuId, $parentId, $name, $desc, $index, $type, $linkType, $url, $visible, &$newId, $contentType, $contentId)
 	{
 		$now = date("Y/m/d H:i:s");	// 現在日時
 		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
@@ -2101,10 +2103,10 @@ class admin_mainDb extends BaseDb
 			if ($ret) $index = $maxRow['ms'] + 1;
 		}
 		$queryStr = 'INSERT INTO _menu_def ';
-		$queryStr .=  '(md_id, md_parent_id, md_index, md_menu_id, md_name, md_description, md_type, md_link_type, md_link_url, md_visible, md_update_user_id, md_update_dt) ';
+		$queryStr .=  '(md_id, md_parent_id, md_index, md_menu_id, md_name, md_description, md_type, md_link_type, md_link_url, md_visible, md_content_type, md_content_id, md_update_user_id, md_update_dt) ';
 		$queryStr .=  'VALUES ';
-		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
-		$this->execStatement($queryStr, array($id, $parentId, $index, $menuId, $name, $desc, $type, $linkType, $url, intval($visible), $userId, $now));
+		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
+		$this->execStatement($queryStr, array($id, $parentId, $index, $menuId, $name, $desc, $type, $linkType, $url, intval($visible), $contentType, $contentId, $userId, $now));
 		
 		// 新規のシリアル番号取得
 		$queryStr = 'select max(md_id) as ns from _menu_def ';
@@ -2125,9 +2127,11 @@ class admin_mainDb extends BaseDb
 	 * @param int     $linkType		リンクタイプ
 	 * @param string  $url			URL
 	 * @param bool    $visible		表示状態
+	 * @param string  $contentType	リンク先コンテンツタイプ
+	 * @param string  $contentId	リンク先コンテンツID
 	 * @return bool					true = 成功、false = 失敗
 	 */
-	function updateMenuItem($id, $name, $desc, $type, $linkType, $url, $visible)
+	function updateMenuItem($id, $name, $desc, $type, $linkType, $url, $visible, $contentType, $contentId)
 	{
 		$now = date("Y/m/d H:i:s");	// 現在日時
 		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
@@ -2143,6 +2147,8 @@ class admin_mainDb extends BaseDb
 		$queryStr .=    'md_link_type = ?, ';		$params[] = $linkType;
 		$queryStr .=    'md_link_url = ?, ';		$params[] = $url;
 		$queryStr .=    'md_visible = ?, ';			$params[] = $visible;
+		$queryStr .=    'md_content_type = ?, ';	$params[] = $contentType;
+		$queryStr .=    'md_content_id = ?, ';		$params[] = $contentId;
 		$queryStr .=    'md_update_user_id = ?, ';	$params[] = $userId;
 		$queryStr .=    'md_update_dt = ? ';		$params[] = $now;
 		$queryStr .=  'WHERE md_id = ? ';			$params[] = $id;
